@@ -285,7 +285,8 @@ function(var,path,pattern,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
     
   # check timestep sorting
   
-  time_sorting <- time1  
+   time_sorting <- time1
+   file_num <- rep(1,length(time_sorting))  
       
   if (fdim>=2){
     for (i in 2:fdim){
@@ -296,9 +297,11 @@ function(var,path,pattern,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
         dum_time <- as.numeric(ncvar_get(id,t_name))
       nc_close(id)
       time_sorting <- append(time_sorting,dum_time)
+      file_num <- append(file_num,rep(i,length(dum_time)))
     }
         
-    filelist <- filelist[order(time_sorting)]
+    file_num <- file_num[order(time_sorting)]
+    filelist <- filelist[unique(file_num)]
     cat("\n","               ")
   }
     
@@ -356,7 +359,7 @@ function(var,path,pattern,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
       }
     }
   } else if (fdim==1) {
-    cat("Just one file corresponds to this pattern.")
+    cat("Just one file matches this pattern.")
   }
   
   nc_close(ncnew)
