@@ -126,19 +126,9 @@ function(var,infile,outfile,nc34=3){
 # extract time information
 
   date.time <- as.Date(get_time(t_units,time1))
-  a <- as.character(date.time)
-  b <- strsplit(a,"-")
-  d <- unlist(b)
-  dummy <- length(d)
-  dum <- seq(2,dummy,3)
-  mon <- as.integer(d[dum])
-  dum <- seq(1,dummy,3)
-  year <- as.integer(d[dum])
-  yl <- as.integer(levels(factor(year)))
-  ml <- as.integer(levels(factor(mon)))
-  nmonmeans <- length(yl)*length(ml)
-  mul <- year*mon
-  dummy_vec <- c(1:length(mon))
+  mon  <- as.integer(format(date.time,"%m"))
+  year <- as.integer(format(date.time,"%Y"))
+  yl   <- as.integer(unique(year))
 
   target <- array(NA,dim=c(length(lon),length(lat),1))
   tbnds <- array(NA, dim=c(2,1))
@@ -219,41 +209,56 @@ function(var,infile,outfile,nc34=3){
 
     id <- nc_open(infile)
     count <- 1
+
     for (i in 1:length(yl)){
-      for (j in 1:4){ 
-        dum_dat <- NULL
+      for (j in 1:4){
+        seas_dummy <- NA
         
         if(j==1){
-          dum <- which(mon==1&year==yl[i]|mon==2&year==yl[i]|mon==12&year==(yl[i]-1))
+          win <- which(mon==1&year==yl[i]|mon==2&year==yl[i]|mon==12&year==(yl[i]-1))
+          if (length(win)>=1){seas_dummy <- win}
         }
         if(j==2){
-          dum <- which(mon==3&year==yl[i]|mon==4&year==yl[i]|mon==5&year==yl[i])
+          spr <- which(mon==3&year==yl[i]|mon==4&year==yl[i]|mon==5&year==yl[i])
+          if (length(spr)>=1){seas_dummy <- spr}
         }
         if(j==3){
-          dum <- which(mon==6&year==yl[i]|mon==7&year==yl[i]|mon==8&year==yl[i])
+          sum <- which(mon==6&year==yl[i]|mon==7&year==yl[i]|mon==8&year==yl[i])
+          if (length(sum)>=1){seas_dummy <- sum}
         }
         if(j==4){
-          dum <- which(mon==9&year==yl[i]|mon==10&year==yl[i]|mon==11&year==yl[i])
+          aut <- which(mon==9&year==yl[i]|mon==10&year==yl[i]|mon==11&year==yl[i])
+          if (length(aut)>=1){seas_dummy <- aut}
         }
         
-        if (length(dum)==3|length(dum)>85){
-          dum_dat <- ncvar_get(id,var,start=c(1,1,dum[1]),count=c(-1,-1,length(dum)),collapse_degen=FALSE)
-          cat("\r","apply seasonal mean ",count," of ",(length(yl)*4),sep="")
-          mean_data <- rowMeans(dum_dat,dims=2,na.rm=T)
-          mean_data[is.na(mean_data)] <- v_missing_value
-          tdum <- min(time1[dum])
-          tbnds[1,1] <- min(time1[dum])
-          tbnds[2,1] <- max(time1[dum])
-          ncvar_put(ncnew,var1,mean_data,start=c(1,1,count),count=c(-1,-1,1))
-          ncvar_put(ncnew,t,tdum,start=count,count=1)
-          ncvar_put(ncnew,var2,tbnds,start=c(1,count),count=c(-1,1))
-          count <- count+1
+        if(!all(is.na(seas_dummy))){
+          dum_dat <- array(NA,dim=c(length(lon),length(lat),length(seas_dummy)))
+          
+          for (k in 1:length(seas_dummy)){
+            if (!is.na(seas_dummy[k])){
+              dum_dat[,,k] <- ncvar_get(id,var,start=c(1,1,seas_dummy[k]),count=c(-1,-1,1),collapse_degen=FALSE)
+            }
+          }
+          
+          if (length(seas_dummy)==3|length(seas_dummy)>85){
+            cat("\r","apply seasonal mean ",count," of ",(length(yl)*4),sep="")
+            mean_data <- rowMeans(dum_dat,dims=2,na.rm=T)
+            mean_data[is.na(mean_data)] <- v_missing_value
+            tdum <- min(time1[seas_dummy],na.rm=T)
+            tbnds[1,1] <- min(time1[seas_dummy],na.rm=T)
+            tbnds[2,1] <- max(time1[seas_dummy],na.rm=T)
+            ncvar_put(ncnew,var1,mean_data,start=c(1,1,count),count=c(-1,-1,1))
+            ncvar_put(ncnew,t,tdum,start=count,count=1)
+            ncvar_put(ncnew,var2,tbnds,start=c(1,count),count=c(-1,1))
+            count <- count+1
+          }
         }
       }
     }
- nc_close(id)
+    
+  nc_close(id)
 
- nc_close(ncnew)
+  nc_close(ncnew)
 
   end.time <- Sys.time()
   cat("\n","processing time: ",round(as.numeric(end.time-start.time,units="secs"),digits=2)," s",sep="", "\n")
